# mypy-boto3-rds

[![PyPI - mypy-boto3-rds](https://img.shields.io/pypi/v/mypy-boto3-rds.svg?color=blue)](https://pypi.org/project/mypy-boto3-rds)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-rds.svg?color=blue)](https://pypi.org/project/mypy-boto3-rds)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-rds](#mypy-boto3-rds)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)

Type annotations for
[boto3.RDS 1.14.0](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/rds.html#RDS) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `RDS` service.

```bash
python -m pip install boto3-stubs[rds]
```

Use `boto3` with `mypy_boto3_rds` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_rds import RDSClient

# Now mypy can check if your code is valid.
client: RDSClient = boto3.client("rds")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: RDSClient = session.client("rds")



# Waiters are also supported

import mypy_boto3_rds.waiter as rds_waiters

db_cluster_snapshot_available_waiter: rds_waiters.DBClusterSnapshotAvailableWaiter = client.get_waiter("db_cluster_snapshot_available")
db_cluster_snapshot_deleted_waiter: rds_waiters.DBClusterSnapshotDeletedWaiter = client.get_waiter("db_cluster_snapshot_deleted")
db_instance_available_waiter: rds_waiters.DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
db_instance_deleted_waiter: rds_waiters.DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
db_snapshot_available_waiter: rds_waiters.DBSnapshotAvailableWaiter = client.get_waiter("db_snapshot_available")
db_snapshot_completed_waiter: rds_waiters.DBSnapshotCompletedWaiter = client.get_waiter("db_snapshot_completed")
db_snapshot_deleted_waiter: rds_waiters.DBSnapshotDeletedWaiter = client.get_waiter("db_snapshot_deleted")


# Annotated paginators are included as well

import mypy_boto3_rds.paginator as rds_paginators

describe_certificates_paginator: rds_paginators.DescribeCertificatesPaginator = client.get_paginator("describe_certificates")
describe_custom_availability_zones_paginator: rds_paginators.DescribeCustomAvailabilityZonesPaginator = client.get_paginator("describe_custom_availability_zones")
describe_db_cluster_backtracks_paginator: rds_paginators.DescribeDBClusterBacktracksPaginator = client.get_paginator("describe_db_cluster_backtracks")
describe_db_cluster_endpoints_paginator: rds_paginators.DescribeDBClusterEndpointsPaginator = client.get_paginator("describe_db_cluster_endpoints")
describe_db_cluster_parameter_groups_paginator: rds_paginators.DescribeDBClusterParameterGroupsPaginator = client.get_paginator("describe_db_cluster_parameter_groups")
describe_db_cluster_parameters_paginator: rds_paginators.DescribeDBClusterParametersPaginator = client.get_paginator("describe_db_cluster_parameters")
describe_db_cluster_snapshots_paginator: rds_paginators.DescribeDBClusterSnapshotsPaginator = client.get_paginator("describe_db_cluster_snapshots")
describe_db_clusters_paginator: rds_paginators.DescribeDBClustersPaginator = client.get_paginator("describe_db_clusters")
describe_db_engine_versions_paginator: rds_paginators.DescribeDBEngineVersionsPaginator = client.get_paginator("describe_db_engine_versions")
describe_db_instance_automated_backups_paginator: rds_paginators.DescribeDBInstanceAutomatedBackupsPaginator = client.get_paginator("describe_db_instance_automated_backups")
describe_db_instances_paginator: rds_paginators.DescribeDBInstancesPaginator = client.get_paginator("describe_db_instances")
describe_db_log_files_paginator: rds_paginators.DescribeDBLogFilesPaginator = client.get_paginator("describe_db_log_files")
describe_db_parameter_groups_paginator: rds_paginators.DescribeDBParameterGroupsPaginator = client.get_paginator("describe_db_parameter_groups")
describe_db_parameters_paginator: rds_paginators.DescribeDBParametersPaginator = client.get_paginator("describe_db_parameters")
describe_db_proxies_paginator: rds_paginators.DescribeDBProxiesPaginator = client.get_paginator("describe_db_proxies")
describe_db_proxy_target_groups_paginator: rds_paginators.DescribeDBProxyTargetGroupsPaginator = client.get_paginator("describe_db_proxy_target_groups")
describe_db_proxy_targets_paginator: rds_paginators.DescribeDBProxyTargetsPaginator = client.get_paginator("describe_db_proxy_targets")
describe_db_security_groups_paginator: rds_paginators.DescribeDBSecurityGroupsPaginator = client.get_paginator("describe_db_security_groups")
describe_db_snapshots_paginator: rds_paginators.DescribeDBSnapshotsPaginator = client.get_paginator("describe_db_snapshots")
describe_db_subnet_groups_paginator: rds_paginators.DescribeDBSubnetGroupsPaginator = client.get_paginator("describe_db_subnet_groups")
describe_engine_default_cluster_parameters_paginator: rds_paginators.DescribeEngineDefaultClusterParametersPaginator = client.get_paginator("describe_engine_default_cluster_parameters")
describe_engine_default_parameters_paginator: rds_paginators.DescribeEngineDefaultParametersPaginator = client.get_paginator("describe_engine_default_parameters")
describe_event_subscriptions_paginator: rds_paginators.DescribeEventSubscriptionsPaginator = client.get_paginator("describe_event_subscriptions")
describe_events_paginator: rds_paginators.DescribeEventsPaginator = client.get_paginator("describe_events")
describe_export_tasks_paginator: rds_paginators.DescribeExportTasksPaginator = client.get_paginator("describe_export_tasks")
describe_global_clusters_paginator: rds_paginators.DescribeGlobalClustersPaginator = client.get_paginator("describe_global_clusters")
describe_installation_media_paginator: rds_paginators.DescribeInstallationMediaPaginator = client.get_paginator("describe_installation_media")
describe_option_group_options_paginator: rds_paginators.DescribeOptionGroupOptionsPaginator = client.get_paginator("describe_option_group_options")
describe_option_groups_paginator: rds_paginators.DescribeOptionGroupsPaginator = client.get_paginator("describe_option_groups")
describe_orderable_db_instance_options_paginator: rds_paginators.DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
describe_pending_maintenance_actions_paginator: rds_paginators.DescribePendingMaintenanceActionsPaginator = client.get_paginator("describe_pending_maintenance_actions")
describe_reserved_db_instances_paginator: rds_paginators.DescribeReservedDBInstancesPaginator = client.get_paginator("describe_reserved_db_instances")
describe_reserved_db_instances_offerings_paginator: rds_paginators.DescribeReservedDBInstancesOfferingsPaginator = client.get_paginator("describe_reserved_db_instances_offerings")
describe_source_regions_paginator: rds_paginators.DescribeSourceRegionsPaginator = client.get_paginator("describe_source_regions")
download_db_log_file_portion_paginator: rds_paginators.DownloadDBLogFilePortionPaginator = client.get_paginator("download_db_log_file_portion")
```

## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_rds` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python
import boto3

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("rds")

session_client = boto3.Session().client("rds")
```